Learn R Programming

MIAmaxent (version 0.4.0)

toydata_selevs: Selected explanatory variables accompanied by selection trails, from toy

Description

Selected explanatory variables and tables showing forward model selection of explanatory variables for distribution modeling of a small, synthetic data set used in Halvorsen (2013). Each individual explanatory variable is represented by a group of derived variables.

Usage

toydata_selevs

Arguments

Format

List with 2 elements:
  1. A list of 5 data frames, where the first 3 represent selected explanatory variables, and the last 2 represent selected interaction terms between these explanatory variables.
  2. A trail of forward model selection used to select explanatory variables and interaction terms.

References

Halvorsen, R. (2013) A strict maximum likelihood explanation of MaxEnt, and some implications for distribution modelling. Sommerfeltia, 36, 1-132.